python-tempestconf
==================

Overview
--------

python-tempestconf will automatically generate the tempest configuration
based on your cloud.

-  Free software: Apache license
-  Documentation: https://docs.openstack.org/python-tempestconf/latest/
-  Source: https://opendev.org/osf/python-tempestconf
-  Bugs: https://storyboard.openstack.org/#!/project/912
-  Release notes: https://docs.openstack.org/releasenotes/python-tempestconf
